@@ -1,8 +1,10 @@
 from .gp import *
 from .krige import *
 from .misc import *
+from .mesh import *
 
 __all__ = []
 __all__.extend(gp.__all__)
 __all__.extend(krige.__all__)
 __all__.extend(misc.__all__)
+__all__.extend(mesh.__all__)
